@@ -254,13 +254,6 @@ function perform_ipmitool_cmd($con, $conf, $machine_id, $ipmi_username, $ipmi_pa
             send_ssh_cmd($conf, $con, $machine["ipaddr"], $cmd);
         }
     }
-    if($conf["hpe"]["live_image_install_hpe"] == "1"){
-        if($machine["product_name"] == "ProLiant DL385 Gen10" || $machine["product_name"] == "ProLiant DL385 Gen10 Plus" || $machine["product_name"] == "ProLiant DL345 Gen11"){
-            $cmd = "hponcfg -f /etc/oci/hpe-activate-ipmi-over-lan.xml";
-            $json["message"] .= "\n$cmd";
-            send_ssh_cmd($conf, $con, $machine["ipaddr"], $cmd);
-        }
-    }
 
     // This sometimes help
     $cmd = "ipmitool lan set 1 arp generate on";
@@ -287,56 +280,41 @@ function perform_ipmitool_cmd($con, $conf, $machine_id, $ipmi_username, $ipmi_pa
     $out = send_ssh_cmd($conf, $con, $machine["ipaddr"], $cmd);
     $json["message"] .= "\n$out";
 
-    if($machine["ipmi_addr"] != $ipmi_addr && ($machine["product_name"] == "ProLiant DL385 Gen10" || $machine["product_name"] == "ProLiant DL385 Gen10 Plus" || $machine["product_name"] == "ProLiant DL345 Gen11")){
+    if($machine["ipmi_addr"] != $ipmi_addr && ($machine["product_name"] == "ProLiant DL385 Gen10" || $machine["product_name"] == "ProLiant DL385 Gen10 Plus" || $machine["product_name"] == "ProLiant DL345 Gen11" || $machine["product_name"] == "ProLiant DL385 Gen11")){
         # Enable the IPMI over LAN, which is off by default on these machines
         $cmd = "echo '<RIBCL VERSION=\\\"2.0\\\"><LOGIN USER_LOGIN=\\\"admin\\\" PASSWORD=\\\"password\\\"><RIB_INFO mode=\\\"write\\\"><MOD_GLOBAL_SETTINGS><IPMI_DCMI_OVER_LAN_ENABLED VALUE=\\\"Y\\\"/></MOD_GLOBAL_SETTINGS></RIB_INFO></LOGIN></RIBCL>' >set-ipmi-on.xml ; hponcfg -f set-ipmi-on.xml ; rm set-ipmi-on.xml";
         $json["message"] .= "\n$cmd";
         $out = send_ssh_cmd($conf, $con, $machine["ipaddr"], $cmd);
         $json["message"] .= "\n$out";
 
-        # Add the ILO license if we have the /root/License.xml file (should be present in the Live OS only)
+        # Also activate IPMI over LAN using ilorest, if the above didn't work.
+        $cmd = "oci-ilorest" . $machine["serial"] . "set --selector NetworkProtocol IPMI/ProtocolEnabled=True --commit";
+        $output = array();
+        $return_var = 0;
+        exec($cmd, $output, $return_var);
+
+        # Add the ILO license if we have the /root/License.xml file (should be present in the Live OS only).
+        # Users of OCI should install the file under:
+        # /etc/openstack-cluster-installer/live-image-additions/root/License.xml
         $cmd = "if [ -e /root/License.xml ] ; then hponcfg -f /root/License.xml ; fi";
         $json["message"] .= "\n$cmd";
         $out = send_ssh_cmd($conf, $con, $machine["ipaddr"], $cmd);
         $json["message"] .= "\n$out";
 
+        if($machine["product_name"] == "ProLiant DL345 Gen11" || $machine["product_name"] == "ProLiant DL385 Gen10 Plus" || $machine["product_name"] == "ProLiant DL385 Gen11"){
+            # Add an SMP community so that we can monitor the system NVMe RAID of these machines
+            $cmd = "oci-ilorest " . $machine["serial"] . 'set ReadCommunities=["snmp_read_string","",""] --selector=HpeiLOSnmpService.v2_3_0 --commit';
+            $output = array();
+            $return_var = 0;
+            exec($cmd, $output, $return_var);
+        }
+
         // Since we changed IP address, the ILO needs a reset (thank you HP !)
-        $cmd = "ipmitool mc reset";
+        $cmd = "ipmitool mc reset cold";
         $json["message"] .= "\n$cmd";
         $out = send_ssh_cmd($conf, $con, $machine["ipaddr"], $cmd);
         $json["message"] .= "\n$out";
     }
-
-    if($machine["ipmi_addr"] != $ipmi_addr && $machine["product_name"] == "ProLiant DL345 Gen11"){
-        # Add an SMP community so that we can monitor the system NVMe RAID of these machines
-        $cmd = "oci-ilorest " . $machine["serial"] . 'set ReadCommunities=["snmp_read_string","",""] --selector=HpeiLOSnmpService.v2_3_0 --commit';
-        $output = array();
-        $return_var = 0;
-        exec($cmd, $output, $return_var);
-    }
-
-#    if($machine["system_manufacturer"] == "HPE"){
-#        # Enable IPMI over LAN
-#        $cmd = "oci-ilorest " . $machine["serial"] . "set --selector=NetworkProtocol IPMI/ProtocolEnabled=True --commit";
-#        $output = array();
-#        $return_var = 0;
-#        exec($cmd, $output, $return_var);
-#
-#        # Install iLO's license
-#        if ($conf["hpe"]["hpe_ilo_install_license"] == "1") {
-#            $cmd = "oci-ilorest " . $machine["serial"] . "ilolicense " . $conf["hpe"]["hpe_ilo_license"];
-#            $output = array();
-#            $return_var = 0;
-#            exec($cmd, $output, $return_var);
-#        }
-#
-#        # Reset so it takes the new IP
-#        $cmd = "oci-ilorest " . $machine["serial"] . "iloreset";
-#        $output = array();
-#        $return_var = 0;
-#        exec($cmd, $output, $return_var);
-#    }
-
     return $json;
 }
 
